@@ -7,7 +7,7 @@ use vars qw($VERSION $BASE_EXC_CLASS %CLASSES);
 
 BEGIN { $BASE_EXC_CLASS ||= 'Exception::Class::Base'; }
 
-$VERSION = '1.11';
+$VERSION = '1.13';
 
 sub import
 {
@@ -204,6 +204,8 @@ BEGIN
 
 1;
 
+sub Classes { sort keys %Exception::Class::CLASSES }
+
 sub throw
 {
     my $proto = shift;
@@ -491,6 +493,13 @@ Foo and never declare Foo.
 
 =over 4
 
+=item * Classes
+
+Returns a list of the classes that have been defined as subclasses of
+Exception::Class.  Note that this is I<all> the subclasses that have
+been created, so it may include subclasses created by things like CPAN
+modules, etc.
+
 =item * Trace($boolean)
 
 Each C<Exception::Class::Base> subclass can be set individually to
@@ -522,6 +531,11 @@ This method defaults to false.  As with C<Trace>, it is inherited by
 subclasses but setting it in a subclass makes it independent
 thereafter.
 
+=item * Fields
+
+This method returns the extra fields defined for the given class, as
+an array.
+
 =item * throw( $message )
 
 =item * throw( message => $message )
